@@ -2,6 +2,7 @@ from dataclasses import dataclass
 from typing import Optional
 
 from helix_personmatching.models.attribute_entry import AttributeEntry
+from helix_personmatching.models.string_match_type import StringMatchType
 
 
 @dataclass
@@ -11,3 +12,4 @@ class RuleAttributeScore:
     present: bool
     source: Optional[str]
     target: Optional[str]
+    string_match_type: Optional[StringMatchType] = None
