@@ -2,6 +2,7 @@ from typing import Optional
 
 from helix_personmatching.logics.rule_score import RuleScore
 from helix_personmatching.logics.scoring_input import ScoringInput
+from helix_personmatching.models.rule_option import RuleOption
 from helix_personmatching.models.rules.RuleWeight import RuleWeight
 
 
@@ -14,5 +15,7 @@ class Rule:
         self.number: int = number
         self.weight: RuleWeight = weight
 
-    def score(self, source: ScoringInput, target: ScoringInput) -> Optional[RuleScore]:
+    def score(
+        self, source: ScoringInput, target: ScoringInput, rule_option: RuleOption
+    ) -> Optional[RuleScore]:
         raise NotImplementedError()
